@@ -16,7 +16,7 @@
 #include "fns.h"
 
 char *version[] = {
-	"9wm version 1.4.0, Copyright (c) 2017 multiple authors", 0,
+	"9wm version 1.4.1, Copyright (c) 2018 multiple authors", 0,
 };
 
 Display *dpy;
@@ -89,9 +89,9 @@ getcolor(Colormap cmap, unsigned long *pixel, char *str)
 	if (str != NULL) {
 		XColor color;
 		Status stpc = 0;
+		Status stac = 0;
 		if (cmap != 0)
 			stpc = XParseColor(dpy, cmap, str, &color);
-		Status stac = 0;
 		if (stpc != 0)
 			stac = XAllocColor(dpy, cmap, &color);
 		if (stac != 0) {
@@ -115,9 +115,12 @@ main(int argc, char *argv[])
 	font = 0;
 	fname = 0;
 	for (i = 1; i < argc; i++)
-		if (strcmp(argv[i], "-debug") == 0)
+		if (strcmp(argv[i], "-debug") == 0) {
 			debug++;
-		else if (strcmp(argv[i], "-font") == 0 && i + 1 < argc)
+#ifndef DEBUG
+		fprintf(stderr,"9wm: WARNING! debug option enabled but debug code not compiled in!\nDebug info may not be complete!\n");
+#endif
+		} else if (strcmp(argv[i], "-font") == 0 && i + 1 < argc)
 			fname = argv[++i];
 		else if (strcmp(argv[i], "-term") == 0 && i + 1 < argc)
 			termprog = argv[++i];
@@ -292,10 +295,10 @@ initscreen(ScreenInfo * s, int i)
 		Colormap cmap = DefaultColormap(dpy,s->num);
 		if (cmap != 0) {
 			unsigned long active;
+			unsigned long inactive;
 			Status sa = getcolor(cmap, &active, activestr);
 			if (sa != 0)
 				s->active = active;
-			unsigned long inactive;
 			Status si = getcolor(cmap, &inactive, inactivestr);
 			if (si != 0)
 				s->inactive = inactive;
