@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014 multiple authors, see README for licence details 
+ * Copyright multiple authors, see README for licence details
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -179,7 +179,7 @@ mapreq(XMapRequestEvent * e)
 		/*
 		 * workaround for stupid NCDware 
 		 */
-		fprintf(stderr, "9wm: bad mapreq c %p w %x, rescanning\n", c, (int) e->window);
+		fprintf(stderr, "9wm: bad mapreq c %p w %x, rescanning\n", (void *) c, (int) e->window);
 		for (i = 0; i < num_screens; i++)
 			scanwins(&screens[i]);
 		c = getclient(e->window, 0);
@@ -318,6 +318,14 @@ clientmesg(XClientMessageEvent * e)
 		Client *c = getclient(e->window, 0);
 		move(c);
 		return;
+	} else if (e->message_type == net_wm_state) {
+		if (e->data.l[1] == net_wm_state_fullscreen || e->data.l[2] == net_wm_state_fullscreen) {
+			if (e->data.l[0] == 1)
+				XChangeProperty(dpy, e->window, net_wm_state, XA_ATOM, 32, PropModeReplace, (unsigned char *)&net_wm_state_fullscreen, 1);
+			else if (e->data.l[0] == 0)
+				XDeleteProperty(dpy, e->window, net_wm_state);
+		}
+		return;
 	} else if (e->message_type == active_window) {
 		Client *c = getclient(e->window, 0);
 		XMapRaised(dpy, c->parent);
@@ -326,9 +334,10 @@ clientmesg(XClientMessageEvent * e)
 		return;
 	} else {
 		char *name;
-		
+
 		name = XGetAtomName(dpy, e->message_type);
-		fprintf(stderr, "9wm: unhandled ClientMessage %s (%d),  window 0x%x\n", name, (int) e->message_type, (int) e->window);
+		fprintf(stderr, "9wm: unhandled ClientMessage %s (%d),  window 0x%x\n", name, (int) e->message_type,
+			(int) e->window);
 		XFree(name);
 	}
 }
