@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014 multiple authors, see README for licence details 
+ * Copyright multiple authors, see README for licence details
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -30,11 +30,9 @@ manage(Client * c, int mapped)
 	if (XGetClassHint(dpy, c->window, &class) != 0) {	/* ``Success'' */
 		c->instance = class.res_name;
 		c->class = class.res_class;
-		c->is9term = (strcmp(c->class, "9term") == 0);
 	} else {
 		c->instance = 0;
 		c->class = 0;
-		c->is9term = 0;
 	}
 	c->iconname = getprop(c->window, XA_WM_ICON_NAME);
 	c->name = getprop(c->window, XA_WM_NAME);
@@ -47,8 +45,6 @@ manage(Client * c, int mapped)
 	getcmaps(c);
 	getproto(c);
 	gettrans(c);
-	if (c->is9term)
-		c->hold = getiprop(c->window, _9wm_hold_mode);
 
 	/*
 	 * Figure out what to do with the window from hints 
@@ -73,17 +69,12 @@ manage(Client * c, int mapped)
 		if (c->trans != None)
 			doreshape = 0;
 	}
-	if (c->is9term)
-		fixsize = 0;
 	if (c->size.flags & PBaseSize) {
 		c->min_dx = c->size.base_width;
 		c->min_dy = c->size.base_height;
 	} else if (c->size.flags & PMinSize) {
 		c->min_dx = c->size.min_width;
 		c->min_dy = c->size.min_height;
-	} else if (c->is9term) {
-		c->min_dx = 100;
-		c->min_dy = 50;
 	} else
 		c->min_dx = c->min_dy = 0;
 
@@ -103,14 +94,14 @@ manage(Client * c, int mapped)
 
 		c->x = x - (c->dx / 2);
 		c->y = y - (c->dy / 2);
-		
+
 		if (c->x + c->dx > xmax) {
 			c->x = xmax - c->dx;
 		}
 		if (c->x < 0) {
 			c->x = 0;
 		}
-		
+
 		if (c->y + c->dy > ymax) {
 			c->y = ymax - c->dy;
 		}
@@ -144,7 +135,7 @@ manage(Client * c, int mapped)
 	else {
 		XMapWindow(dpy, c->window);
 		XMapWindow(dpy, c->parent);
-		if (nostalgia || doreshape)
+		if (doreshape)
 			active(c);
 		else if (c->trans != None && current && current->window == c->trans)
 			active(c);
